WidgetBookWidgetField class

Constructors

WidgetBookWidgetField({dynamic defaultValue, bool ignore = false, List options = const []})
const

Properties

defaultValue → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
ignore bool
If ignore is set to true, then no default value (using knobs) will be generated for this field
final
options List
If options is set, then the field will be treated as a list of options and the list knob will be used
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited